@@ -1,77 +1,64 @@
 package XAS::Base;
 
-our $MESSAGES;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 our $EXCEPTION = 'XAS::Exception';
 
 use XAS::Factory;
 use XAS::Exception;
-use Params::Validate ':all';
 
 use XAS::Class
-  debug      => 0,
-  version    => $VERSION,
-  base       => 'Badger::Base',
-  utils      => 'dotid',
-  auto_can   => '_auto_load',
-  accessors  => 'env',
-  filesystem => 'Dir',
+  debug    => 0,
+  version  => $VERSION,
+  base     => 'Badger::Base',
+  utils    => ':validation xprintf dotid',
+  import   => 'class',
+  auto_can => '_auto_load',
   vars => {
     PARAMS => {
-      -alerts => { optional => 1, default => 0 },
-      -xdebug => { optional => 1, default => 0 },
-    },
+      -xdebug => { optional => 1, default => 0 }
+    }
   }
 ;
 
-use Data::Dumper;
+#use Data::Dumper;
+
+# ----------------------------------------------------------------------
+# Overrides
+# ----------------------------------------------------------------------
+
+class('Badger::Base')->methods(
+    message => sub {
+        my $self = shift;
+        my $name = shift
+          || $self->fatal("message() called without format name");
+
+        my $m1 = XAS::Base->env->get_msgs;
+        my $m2 = $self->class->all_vars('MESSAGES');
+
+        foreach my $h (@$m2) {
+
+            while (my ($key, $value) = each(%$h)) {
+
+                $m1->{$key} = $value;
+
+            }
+
+        }
+
+        $self->class->var('MESSAGES', $m1);
+
+        my $format = $self->class->hash_value('MESSAGES', $name)
+          || $self->fatal("message() called with invalid message type: $name");
+
+        xprintf($format, @_);
+
+    }
+);
 
 # ----------------------------------------------------------------------
 # Public Methods
 # ----------------------------------------------------------------------
 
-sub validation_exception {
-    my $param = shift;
-    my $class = shift;
-
-    my $method = dotid($class) . '.invparams';
-    $param = lcfirst($param);
-
-    __PACKAGE__->throw_msg($method, 'invparams', $param);
-
-}
-
-sub validate_params {
-    my $self   = shift;
-    my $params = shift;
-    my $specs  = shift;
-    my $class  = shift;
-
-    unless (defined($class)) {
-
-        $class = (caller(1))[3];
-
-    }
-
-    my $results = validate_with(
-        params => $params,
-        called => $class,
-        spec   => $specs,
-        normalize_keys => sub {
-            my $key = shift; 
-            $key =~ s/^-//; 
-            return lc $key;
-        },
-        on_fail => sub {
-            my $param = shift;
-            validation_exception($param, $class);
-        },
-    );
-
-    return wantarray ? @$results : $results;
-
-}
-
 # ----------------------------------------------------------------------
 # Private Methods
 # ----------------------------------------------------------------------
@@ -84,28 +71,17 @@ sub _auto_load {
 
         return sub { XAS::Factory->module('alert'); } 
 
-    }
-
-    if ($name eq 'email') {
+    } elsif ($name eq 'email') {
 
         return sub { XAS::Factory->module('email'); } 
 
-    }
+    } elsif ($name eq 'log') {
 
-    if ($name eq 'log') {
+        return sub { XAS::Factory->module('logger'); } 
 
-        return sub { 
+    } elsif ($name eq 'env') {
 
-            XAS::Factory->module('logger', {
-                -type     => $self->env->log_type,
-                -filename => $self->env->logfile,
-                -process  => $self->env->script,
-                -levels => {
-                    debug => $self->env->xdebug,
-                }
-            }); 
-
-        }
+        return sub { XAS::Factory->module('environment'); }
 
     }
 
@@ -141,27 +117,17 @@ sub _create_methods {
 sub init {
     my $self = shift;
 
-    # load the environment
-
-    $self->{env} = XAS::Factory->module('environment');
-    $XAS::Base::MESSAGES = $self->env->get_msgs();
-
     # process PARAMS
 
     my $class = $self->class;
     my $params = $self->class->hash_vars('PARAMS');
-    my $p = $self->validate_params(\@_, $params, $class);
+    my $p = validate_params(\@_, $params, $class);
 
     # build our object
 
-    $self->{config} = $p;
+    $self->{'config'} = $p;
     $self->_create_methods($p);
 
-    # set defaults
-
-    $self->env->alerts($self->alerts);
-    $self->env->xdebug($self->xdebug);
-
     return $self;
 
 }
@@ -176,8 +142,11 @@ XAS::Base - The base class for the XAS environment
 
 =head1 SYNOPSIS
 
+ our $VERSION = '0.01';
+
  use XAS::Class
-   version => '0.01',
+   debug   => 0,
+   version => $VERSION,
    base    => 'XAS::Base',
    vars => {
        PARAMS => {}
@@ -201,57 +170,6 @@ auto-magically become accessors toward their values.
 This is used to initialized the class. These parameters are validated using 
 the validate_params() method. 
 
-By default the parameter -xdebug is set to 0. This parameter is used to
-turn on debugging output.
-
-=head2 validate_params($params, $spec, $class)
-
-This method is used to validate parameters. Internally this uses 
-Params::Validate::validate_with() for the parameter validation. 
-
-By convention, all named parameters have a leading dash. This method will 
-strip off that dash and lower case the parameters name.
-
-If an validation exception is thrown, the parameter name will have the dash 
-stripped.
-
-Based on the $spec, this can return an array or a hashref of validated
-parameters and values. 
-
-=over 4
-
-=item B<$params>
-
-An array ref to a set of parameters. 
-
-=item B<$spec>
-
-A validation spec as defined by L<Params::Validate|https://metacpan.org/pod/Params::Validate>.
-
-=item B<$class>
-
-An optional class that is calling this method. If one is not provided then
-caller() is used to determine the calling method.
-
-=back
-
-=head2 validation_exception($param, $class)
-
-This is a package level sub routine. It exists to provide a uniform exception
-error message. It takes these parameters:
-
-=over 4
-
-=item B<$param>
-
-The error message returned by L<Params::Validate|https://metacpan.org/pod/Params::Validate>.
-
-=item B<$class>
-
-The routine that the error occurred in.
-
-=back
-
 =head1 AUTOLOADING
 
 Specific modules can be auto-loaded when a method name is invoked. The 
@@ -274,7 +192,7 @@ Please see that module for more details.
 
 =head2 log
 
-This will auto load L<XAS::Lib::Modules::Log|XAS::Lib::Modules::Log>.
+This will auto load L<XAS::Lib::Log|XAS::Lib::Log>.
 Please see that module for more details.
 
 =head1 SEE ALSO
@@ -291,9 +209,9 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
-TThis is free software; you can redistribute it and/or modify it under
+This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
 of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
