@@ -1,7 +1,6 @@
 package XAS::Lib::Pidfile;
 
 our $VERSION = '0.01';
-
 my $mixin;
 
 BEGIN {
@@ -9,7 +8,8 @@ BEGIN {
     $mixin = 'XAS::Lib::Pidfile::Win32' if ($^O eq 'MSWin32');
 }
 
-use XAS::Lib::Modules::Locking;
+use XAS::Factory;
+use File::Basename;
 
 use XAS::Class
   debug      => 0,
@@ -17,7 +17,7 @@ use XAS::Class
   base       => 'XAS::Base',
   mixin      => $mixin,
   utils      => 'trim dotid',
-  accessors  => 'lockmgr',
+  accessors  => 'lockmgr lock',
   filesystem => 'Dir',
   vars => {
     PARAMS => {
@@ -37,7 +37,8 @@ sub write {
     my $self = shift;
 
     my $stat = 0;
-    my $lock = Dir($self->file->volume, $self->file->directory);
+    my $lock = $self->lock;
+
     my $output = sub {
 
         my $fh = $self->file->open('w');
@@ -46,7 +47,7 @@ sub write {
 
     };
 
-    if ($self->lockmgr->lock_directory($lock)) {
+    if ($self->lockmgr->lock($lock)) {
 
         if ($self->file->exists) {
 
@@ -60,7 +61,7 @@ sub write {
         }
 
         $stat = 1;
-        $self->lockmgr->unlock_directory($lock);
+        $self->lockmgr->unlock($lock);
 
     }
 
@@ -71,18 +72,22 @@ sub write {
 sub remove {
     my $self = shift;
 
-    my $lock = Dir($self->file->volume, $self->file->directory);
+    my $lock = $self->lock;
+    my $pid = $self->_get_pid;
 
-    if ($self->lockmgr->lock_directory($lock)) {
+    if ($pid == $$) {
 
-        $self->file->delete() if ($self->file->exists);
-        $self->lockmgr->unlock_directory($lock);
+        if ($self->lockmgr->lock($lock)) {
+
+            $self->file->delete() if ($self->file->exists);
+            $self->lockmgr->unlock($lock);
+
+        }
 
     }
 
 }
 
-
 # ----------------------------------------------------------------------
 # Private Methods
 # ----------------------------------------------------------------------
@@ -91,9 +96,9 @@ sub _get_pid {
     my $self = shift;
 
     my $pid = undef;
-    my $lock = Dir($self->file->volume, $self->file->directory);
+    my $lock = $self->lock;
 
-    if ($self->lockmgr->lock_directory($lock)) {
+    if ($self->lockmgr->lock($lock)) {
 
         if ($self->file->exists) {
 
@@ -104,7 +109,7 @@ sub _get_pid {
 
         }
 
-        $self->lockmgr->unlock_directory($lock);
+        $self->lockmgr->unlock($lock);
 
     }
 
@@ -117,14 +122,22 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
 
-    $self->{lockmgr} = XAS::Lib::Modules::Locking->new();
+    unless (defined($self->{'file'})) {
 
-    unless (defined($self->{file})) {
-
-        $self->{file} = $self->env->pidfile;
+        $self->{'file'} = $self->env->pid_file;
 
     }
 
+    my $basename = fileparse($self->env->script, qr/\.[^.]*/);
+
+    $self->{'lock'} = Dir($self->file->volume, $self->file->directory, $basename)->path;
+    $self->{'lockmgr'} = XAS::Factory->module('lockmgr');
+
+    $self->lockmgr->add(
+        -key    => $self->lock,
+        -driver => 'Filesystem',
+    );
+
     return $self;
 
 }
@@ -204,6 +217,10 @@ Remove the current pid file.
 
 =over 4
 
+=item L<XAS::Lib::Pidfile::Unix|XAS::Lib::Pidfile::Unix>
+
+=item L<XAS::Lib::Pidfile::Win32|XAS::Lib::Pidfile::Win32>
+
 =item L<XAS|XAS>
 
 =back
@@ -214,7 +231,7 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 TThis is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
