@@ -11,9 +11,9 @@ use XAS::Class
   version   => $VERSION,
   base      => 'XAS::Base',
   mixin     => 'XAS::Lib::Mixins::Bufops',
-  accessors => 'ssh chan sock select',
+  accessors => 'ssh chan sock select exit_code exit_signal',
   mutators  => 'attempts', 
-  utils     => 'trim dotid',
+  utils     => ':validation dotid trim',
   import    => 'class',
   vars => {
     PARAMS => {
@@ -84,9 +84,9 @@ sub connect {
 
         }
 
-        $self->{sock}   = $self->ssh->sock();
-        $self->{chan}   = $self->ssh->channel();
-        $self->{select} = IO::Select->new($self->sock);
+        $self->{'sock'}   = $self->ssh->sock();
+        $self->{'chan'}   = $self->ssh->channel();
+        $self->{'select'} = IO::Select->new($self->sock);
 
         $self->setup();
 
@@ -115,7 +115,7 @@ sub setup {
 sub pending {
     my $self = shift;
 
-    return length($self->{buffer});
+    return length($self->{'buffer'});
 
 }
 
@@ -129,22 +129,24 @@ sub disconnect {
 
     }
 
-    $self->ssh->disconnect();
+    if (my $ssh = $self->ssh) {
+
+        $ssh->disconnect();
+
+    }
 
 }
 
 sub get {
     my $self = shift;
-    my ($length) = $self->validate_params(\@_, [
+    my ($length) = validate_params(\@_, [
         { optional => 1, default => 512 }
     ]);
 
-    my $state  = 1;
     my $output = '';
-    my $working = 1;
 
     # extract $length from buffer. if the buffer size is > $length then
-    # try to refill buffer. If there is nothing to read, the return
+    # try to refill buffer. If there is nothing to read, then return
     # the remainder of the buffer.
     #
     # Patterned after some libssh2 examples and C network programming
@@ -152,14 +154,14 @@ sub get {
 
     if ($self->pending > $length) {
 
-        $output = $self->buf_slurp(\$self->{buffer}, $length);
+        $output = $self->buf_slurp(\$self->{'buffer'}, $length);
 
     } else {
 
         $self->_fill_buffer();
 
         my $l = ($self->pending > $length) ? $length : $self->pending;
-        $output = $self->buf_slurp(\$self->{buffer}, $l);
+        $output = $self->buf_slurp(\$self->{'buffer'}, $l);
 
     }
 
@@ -179,7 +181,7 @@ sub gets {
 
         if ($output = $self->buf_get_line(\$buffer, $self->eol)) {
 
-            $self->{buffer} = $buffer . $self->{buffer};
+            $self->{'buffer'} = $buffer . $self->{'buffer'};
             last;
 
         }
@@ -192,7 +194,7 @@ sub gets {
 
 sub put {
     my $self = shift;
-    my ($buffer) = $self->validate_params(\@_, [1]);
+    my ($buffer) = validate_params(\@_, [1]);
 
     my $counter = 0;
     my $working = 1;
@@ -255,7 +257,7 @@ sub put {
 
 sub puts {
     my $self = shift;
-    my ($buffer) = $self->validate_params(\@_, [1]);
+    my ($buffer) = validate_params(\@_, [1]);
 
     my $output  = sprintf("%s%s", trim($buffer), $self->eol);
     my $written = $self->put($output);
@@ -266,7 +268,7 @@ sub puts {
 
 sub errno {
     my $class = shift;
-    my ($value) = XAS::Base->validate_params(\@_, [
+    my ($value) = validate_params(\@_, [
         { optional => 1, default => undef }
     ]);
 
@@ -278,7 +280,7 @@ sub errno {
 
 sub errstr {
     my $class = shift;
-    my ($value) = XAS::Base->validate_params(\@_, [
+    my ($value) = validate_params(\@_, [
         { optional => 1, default => undef }
     ]);
 
@@ -304,8 +306,8 @@ sub init {
 
     my $self = $class->SUPER::init(@_);
 
-    $self->{ssh} = Net::SSH2->new();
-    $self->{buffer} = '';
+    $self->{'ssh'} = Net::SSH2->new();
+    $self->{'buffer'} = '';
 
     $self->attempts(5);       # number of EAGAIN attempts
 
@@ -331,7 +333,7 @@ sub _fill_buffer {
 
         if (my $bytes = $self->chan->read($buf, 512)) {
 
-            $self->{buffer} .= $buf;
+            $self->{'buffer'} .= $buf;
             $read += $bytes;
 
         } else {
@@ -546,6 +548,16 @@ error occurs. The default is 5 times.
 
 =over 4
 
+=item L<XAS::Lib::SSH::Server|XAS::Lib::SSH::Server>
+
+=item L<XAS::Lib::SSH::Client::Exec|XAS::Lib::SSH::Client::Exec>
+
+=item L<XAS::Lib::SSH::Client::Shell|XAS::Lib::SSH::Client::Shell>
+
+=item L<XAS::Lib::SSH::Client::Subsystem|XAS::Lib::SSH::Client::Subsystem>
+
+=item L<Net::SSH2|https://metacpan.org/pod/Net::SSH2>
+
 =item L<XAS|XAS>
 
 =back
@@ -556,11 +568,10 @@ Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 Kevin L. Esteb
+Copyright (c) 2012-2015 Kevin L. Esteb
 
 This is free software; you can redistribute it and/or modify it under
 the terms of the Artistic License 2.0. For details, see the full text
 of the license at http://www.perlfoundation.org/artistic_license_2_0.
 
 =cut
-
