@@ -1,13 +1,20 @@
 package XAS::Lib::Stomp::Utils;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use XAS::Lib::Stomp::Frame;
+use XAS::Constants ':stomp';
 
 use XAS::Class
   debug   => 0,
   version => $VERSION,
   base    => 'XAS::Base',
+  utils   => ':validation',
+  vars => {
+    PARAMS => {
+      -target  => { optional => 1, default => undef, regex => STOMP_LEVELS },
+    }
+  }
 ;
 
 #use Data::Dumper;
@@ -18,7 +25,7 @@ use XAS::Class
 
 sub connect {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -login      => { optional => 1, default => undef },
         -passcode   => { optional => 1, default => undef },
         -host       => { optional => 1, default => 'localhost' },
@@ -36,7 +43,7 @@ sub connect {
     $header->{'login'}    = $p->{'login'}    if (defined($p->{'login'}));
     $header->{'passcode'} = $p->{'passcode'} if (defined($p->{'passcode'}));
 
-    if ($self->env->mqlevel > 1.0) {
+    if ($self->target > 1.0) {
 
         $header->{'host'}           = $p->{'host'};
         $header->{'heart-beat'}     = $p->{'heart_beat'};
@@ -56,7 +63,7 @@ sub connect {
 
 sub stomp {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -login      => { optional => 1, default => undef },
         -passcode   => { optional => 1, default => undef },
         -prefetch   => { optional => 1, default => undef },
@@ -74,12 +81,12 @@ sub stomp {
     my $frame;
     my $header = {};
 
-    if ($self->env->mqlevel == 1.0) {
+    if ($self->target == 1.0) {
 
         $self->throw_msg(
             'xas.lib.stomp.utils.stomp.nosup',
             'stomp_no_support',
-            $self->env->mqlevel,
+            $self->target,
             'stomp'
         );
 
@@ -89,7 +96,7 @@ sub stomp {
     $header->{'passcode'}      = $p->{'passcode'} if (defined($p->{'passcode'}));
     $header->{'prefetch-size'} = $p->{'prefetch'} if (defined($p->{'prefetch'}));
 
-    if ($self->env->mqlevel > 1.0) {
+    if ($self->target > 1.0) {
 
         $header->{'host'}           = $p->{'host'};
         $header->{'heart-beat'}     = $p->{'heart_beat'};
@@ -109,7 +116,7 @@ sub stomp {
 
 sub subscribe {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -destination  => 1,
         -prefetch     => { optional => 1, default => 0 },
         -id           => { optional => 1, default => undef },
@@ -125,7 +132,7 @@ sub subscribe {
     $header->{'destination'}    = $p->{'destination'};
     $header->{'receipt'}        = $p->{'receipt'} if (defined($p->{'receipt'}));
 
-    if (defined($p->{'-id'})) {
+    if (defined($p->{'id'})) {
 
         $header->{'id'} = $p->{'id'};
 
@@ -133,12 +140,12 @@ sub subscribe {
 
         # v1.1 and greater must have an id header
 
-        if ($self->env->mqlevel > 1.0) {
+        if ($self->target > 1.0) {
 
             $self->throw_msg(
                 'xas.lib.stomp.utils.subscribe',
                 'stomp_no_id',
-                $self->env->mqlevel
+                $self->target
                 
             );
 
@@ -158,7 +165,7 @@ sub subscribe {
 
 sub unsubscribe {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -id           => { optional => 1, default => undef },
         -destination  => { optional => 1, default => undef },
         -receipt      => { optional => 1, default => undef },
@@ -190,12 +197,12 @@ sub unsubscribe {
         $self->throw_msg(
             'xas.lib.stomp.utils.unsubscribe.invparams',
             'stomp_invalid_params',
-            $self->env->mqlevel
+            $self->target
         );
 
     }
 
-    if ($self->env->mqlevel > 1.0) {
+    if ($self->target > 1.0) {
 
         # v1.1 and greater must have an id header
 
@@ -204,7 +211,7 @@ sub unsubscribe {
             $self->throw_msg(
                 'xas.lib.stomp.utils.unsubscribe.noid',
                 'stomp_no_id',
-                $self->env->mqlevel
+                $self->target
             );
 
         }
@@ -223,7 +230,7 @@ sub unsubscribe {
 
 sub begin {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -transaction => 1,
         -receipt     => { optional => 1, default => undef },
     });
@@ -246,7 +253,7 @@ sub begin {
 
 sub commit {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -transaction => 1,
         -receipt     => { optional => 1, default => undef },
     });
@@ -269,7 +276,7 @@ sub commit {
 
 sub abort {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -transaction => 1,
         -receipt     => { optional => 1, default => undef },
     });
@@ -292,7 +299,7 @@ sub abort {
 
 sub ack {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -message_id   => 1,
         -subscription => { optional => 1, default => undef },
         -receipt      => { optional => 1, default => undef },
@@ -305,7 +312,7 @@ sub ack {
     $header->{'receipt'}     = $p->{'receipt'}     if (defined($p->{'receipt'}));
     $header->{'transaction'} = $p->{'transaction'} if (defined($p->{'transaction'}));
 
-    if ($self->env->mqlevel < 1.2) {
+    if ($self->target < 1.2) {
 
         $header->{'message-id'} = $p->{'message_id'};
 
@@ -321,12 +328,12 @@ sub ack {
 
     } else {
 
-        if ($self->env->mqlevel > 1.0) {
+        if ($self->target > 1.0) {
 
             $self->throw_msg(
                 'xas.lib.stomp.utils.ack.nosup',
                 'stomp_no_subscription',
-                $self->env->mqlevel
+                $self->target
             );
 
         }
@@ -345,7 +352,7 @@ sub ack {
 
 sub nack {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -message_id   => 1,
         -receipt      => { optional => 1, default => undef },
         -subscription => { optional => 1, default => undef },
@@ -358,18 +365,18 @@ sub nack {
     $header->{'receipt'}     = $p->{'receipt'}     if (defined($p->{'receipt'}));
     $header->{'transaction'} = $p->{'transaction'} if (defined($p->{'transaction'}));
 
-    if ($self->env->mqlevel == 1.0) {
+    if ($self->target == 1.0) {
 
         $self->throw_msg(
             'xas.lib.stomp.utils.nack',
             'stomp_no_support',
-            $self->env->mqlevel,
+            $self->target,
             'nack'
         );
 
     }
 
-    if ($self->env->mqlevel < 1.2) {
+    if ($self->target < 1.2) {
 
         $header->{'message-id'} = $p->{'message_id'};
 
@@ -385,12 +392,12 @@ sub nack {
 
     } else {
 
-        if ($self->env->mqlevel > 1.0) {
+        if ($self->target > 1.0) {
 
             $self->throw_msg(
                 'xas.lib.stomp.utils.nact',
                 'stomp_no_support',
-                $self->env->mqlevel,
+                $self->target,
                 'nack'
             );
 
@@ -410,7 +417,7 @@ sub nack {
 
 sub disconnect {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -receipt => { optional => 1, default => undef }
     });
 
@@ -431,7 +438,7 @@ sub disconnect {
 
 sub send {
     my $self = shift;
-    my $p = $self->validate_params(\@_, {
+    my $p = validate_params(\@_, {
         -destination => 1,
         -message     => 1,
         -receipt     => { optional => 1, default => undef },
@@ -454,7 +461,7 @@ sub send {
         $header->{'content-length'} = defined($p->{'length'}) ? $p->{'length'} : length($body);
     }
 
-    if ($self->env->mqlevel > 1.0) {
+    if ($self->target > 1.0) {
 
         $header->{'content-type'} = $p->{'type'};
 
@@ -475,12 +482,12 @@ sub noop {
 
     my $frame;
 
-    if ($self->env->mqlevel == 1.0) {
+    if ($self->target == 1.0) {
 
         $self->throw_msg(
             'xas.lib.stomp.utils.noop.nosup',
             'stomp_no_support',
-            $self->env->mqlevel,
+            $self->target,
             'noop'
         );
 
@@ -500,6 +507,21 @@ sub noop {
 # Private Methods
 # -----------------------------------------------------------
 
+sub init {
+    my $class = shift;
+
+    my $self = $class->SUPER::init(@_);
+
+    unless (defined($self->{target})) {
+
+        $self->{target} = $self->env->mqlevel;
+
+    }
+
+    return $self;
+
+}
+
 sub _match {
     my $buffer = shift;
 
